summaryrefslogtreecommitdiff
path: root/examples/hlapi/asyncore/sync/manager/cmdgen/preload-pysnmp-mibs.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/hlapi/asyncore/sync/manager/cmdgen/preload-pysnmp-mibs.py')
-rw-r--r--examples/hlapi/asyncore/sync/manager/cmdgen/preload-pysnmp-mibs.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/hlapi/asyncore/sync/manager/cmdgen/preload-pysnmp-mibs.py b/examples/hlapi/asyncore/sync/manager/cmdgen/preload-pysnmp-mibs.py
index 27186431..a9bb2bb3 100644
--- a/examples/hlapi/asyncore/sync/manager/cmdgen/preload-pysnmp-mibs.py
+++ b/examples/hlapi/asyncore/sync/manager/cmdgen/preload-pysnmp-mibs.py
@@ -5,14 +5,14 @@ Preload PySNMP MIBs
Send a series of SNMP GETNEXT requests using the following options:
* with SNMPv3 with user 'usr-md5-des', MD5 auth and DES privacy protocols
* over IPv6/UDP
* to an Agent at [::1]:161
* for all OIDs starting from 1.3.6
* preload all Python MIB modules found in search path
Functionally similar to:
-| $ snmpwalk -v3 -l authPriv -u usr-md5-des -A authkey1 -X privkey1 -m ALL udp6:[::1]:161 1.3.6
+| $ snmpwalk -v3 -l authPriv -u usr-md5-des -A authkey1 -X privkey1 -m ALL demo.snmplabs.com:161 1.3.6
"""#
from pysnmp.hlapi import *
@@ -22,7 +22,7 @@ for (errorIndication,
errorIndex,
varBinds) in nextCmd(SnmpEngine(),
UsmUserData('usr-md5-des', 'authkey1', 'privkey1'),
- Udp6TransportTarget(('::1', 161)),
+ UdpTransportTarget(('demo.snmplabs.com', 161)),
ContextData(),
ObjectType(ObjectIdentity('1.3.6').loadMibs())):
@@ -5,14 +5,14 @@ Preload PySNMP MIBs
Send a series of SNMP GETNEXT requests using the following options:
* with SNMPv3 with user 'usr-md5-des', MD5 auth and DES privacy protocols
-* over IPv6/UDP
-* to an Agent at [::1]:161
+* over IPv4/UDP
+* to an Agent at demo.snmplabs.com:161
* for all OIDs starting from 1.3.6
* preload all Python MIB modules found in search path